webbpsf\_ext.spectra.planets\_sb12
==================================

.. currentmodule:: webbpsf_ext.spectra

.. autoclass:: planets_sb12
   :members:
   :inherited-members:
   :show-inheritance:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~planets_sb12.__init__
      ~planets_sb12.export_pysynphot
      ~planets_sb12.export_synphot
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~planets_sb12.age
      ~planets_sb12.atmo
      ~planets_sb12.distance
      ~planets_sb12.entropy
      ~planets_sb12.flux
      ~planets_sb12.fluxunits
      ~planets_sb12.mass
      ~planets_sb12.mdot
      ~planets_sb12.sub_dir
      ~planets_sb12.wave
      ~planets_sb12.waveunits
   
   